@@ -1,4 +1,4 @@
-import six
+from functools import wraps
 import sys
 
 from .constants import OK, CREATED, ACCEPTED, NO_CONTENT
@@ -13,6 +13,7 @@ def skip_prepare(func):
     """
     A convenience decorator for indicating the raw data should not be prepared.
     """
+    @wraps(func)
     def _wrapper(self, *args, **kwargs):
         value = func(self, *args, **kwargs)
         return Data(value, should_prepare=False)
@@ -132,6 +133,7 @@ class Resource(object):
 
         :returns: View function
         """
+        @wraps(cls)
         def _wrapper(request, *args, **kwargs):
             # Make a new instance so that no state potentially leaks between
             # instances.
