@@ -1,17 +1,23 @@
 import unittest
 
 try:
+    from http.client import responses
+except ImportError:
+    from httplib import responses
+
+try:
+    from django.conf import settings
+except ImportError:
+    settings = None
+    DjangoResource = object
+else:
     from django.http import Http404
     from django.core.exceptions import ObjectDoesNotExist
 
     # Ugh. Settings for Django.
-    from django.conf import settings
     settings.configure(DEBUG=True)
 
     from restless.dj import DjangoResource
-except ImportError:
-    settings = None
-    DjangoResource = object
 
 from restless.exceptions import Unauthorized
 from restless.preparers import FieldsPreparer
@@ -222,6 +228,8 @@ class DjangoResourceTestCase(unittest.TestCase):
         resp = self.res.handle('list')
         self.assertEqual(resp['Content-Type'], 'application/json')
         self.assertEqual(resp.status_code, 501)
+        self.assertEqual(resp.reason_phrase.title(), responses[501])
+
         resp_json = json.loads(resp.content.decode('utf-8'))
         self.assertEqual(
             resp_json['error'], "Unsupported method 'TRACE' for list endpoint.")
@@ -235,6 +243,8 @@ class DjangoResourceTestCase(unittest.TestCase):
         resp = self.res.handle('list')
         self.assertEqual(resp['Content-Type'], 'application/json')
         self.assertEqual(resp.status_code, 401)
+        self.assertEqual(resp.reason_phrase.title(), responses[401])
+
         resp_json = json.loads(resp.content.decode('utf-8'))
         self.assertEqual(resp_json['error'], 'Unauthorized.')
         self.assertTrue('traceback' in resp_json)
@@ -270,6 +280,7 @@ class DjangoResourceTestCase(unittest.TestCase):
         resp = self.res.handle('detail')
         self.assertEqual(resp['Content-Type'], 'application/json')
         self.assertEqual(resp.status_code, 500)
+        self.assertEqual(resp.reason_phrase.title(), responses[500])
         self.assertEqual(json.loads(resp.content.decode('utf-8')), {
             'error': {
                 'code': 'random-crazy',
@@ -287,6 +298,7 @@ class DjangoResourceTestCase(unittest.TestCase):
         resp = self.res.handle('detail', 1001)
         self.assertEqual(resp['Content-Type'], 'application/json')
         self.assertEqual(resp.status_code, 404)
+        self.assertEqual(resp.reason_phrase.title(), responses[404])
         self.assertEqual(json.loads(resp.content.decode('utf-8')), {
             'error': 'Model with pk 1001 not found.'
         })
@@ -302,6 +314,7 @@ class DjangoResourceTestCase(unittest.TestCase):
         resp = res.handle('detail', 1001)
         self.assertEqual(resp['Content-Type'], 'application/json')
         self.assertEqual(resp.status_code, 404)
+        self.assertEqual(resp.reason_phrase.title(), responses[404])
         self.assertEqual(json.loads(resp.content.decode('utf-8')), {
             'error': 'Model with pk 1001 not found.'
         })
