@@ -1,7 +1,9 @@
 import datetime
 from decimal import Decimal
 import unittest
+import uuid
 
+from restless.exceptions import BadRequest
 from restless.serializers import JSONSerializer
 
 
@@ -17,6 +19,7 @@ class JSONSerializerTestCase(unittest.TestCase):
                 # Some data the usual JSON encoder can't handle...
                 'nested': datetime.datetime(2014, 3, 30, 12, 55, 15),
                 'again': Decimal('18.9'),
+                'uuid': uuid.uuid4()
             },
         }
 
@@ -31,3 +34,7 @@ class JSONSerializerTestCase(unittest.TestCase):
         self.assertEqual(self.serializer.deserialize('{"more": "things"}'), {
             'more': 'things',
         })
+
+    def test_deserialize_invalid(self):
+        with self.assertRaises(BadRequest):
+            self.serializer.deserialize('not valid!')
